@@ -65,7 +65,9 @@ LOG = logging.getLogger(__name__)
 
 
 # TODO(sbaker): fix tests so that sqlite_fk=True can be passed to configure
-db_context.configure()
+# FIXME(stephenfin): we need to remove reliance on autocommit semantics ASAP
+# since it's not compatible with SQLAlchemy 2.0
+db_context.configure(__autocommit=True)
 
 
 def get_facade():
@@ -542,7 +544,7 @@ def resource_get_all_active_by_stack(context, stack_id):
 
     results = context.session.query(models.Resource).filter_by(
         stack_id=stack_id).filter(
-        models.Resource.id.notin_(subquery.as_scalar())
+        models.Resource.id.notin_(subquery.scalar_subquery())
     ).options(orm.joinedload("data")).all()
 
     return dict((res.id, res) for res in results)
